MODULE MakeDirs;

IMPORT
  d := Dos,
  e := Exec;

CONST
  template =  "NAME/A,COUNT/N"
              "\o$VER: MakeDirs.mod 42.3 (05.04.95)\o";
  defCount  = 32 - 1;

TYPE
  Args = STRUCT (as :d.ArgsStruct);
           name     :d.ArgString;
           count    :d.ArgLong;
           files    :d.ArgBool;
           flat     :d.ArgBool;
         END;

VAR
  arguments :d.RDArgsPtr;
  argv      :Args;
  name      :e.LSTRPTR;
  count     :LONGINT;
  files,
  flat      :BOOLEAN;
  buff      :ARRAY 30 OF CHAR;
  prevDir,
  newDir,
  oldCD     :d.FileLockPtr;

BEGIN
  arguments := d.ReadArgs(template, argv, NIL);
  IF arguments=NIL THEN
    IF d.PrintFault(d.IoErr(),"MakeDirs") THEN END;
    HALT(20)
  END;
  IF argv.count#NIL THEN
    (* subtract 1 because the one dir is created outside
    ** of the loop in which the counter gets decremented *)
    count := argv.count[0] - 1;
  ELSE
    count := defCount;
  END;
  name := d.FilePart(argv.name^);

  newDir := d.CreateDir(argv.name^);
  IF newDir=NIL THEN
    IF d.PrintFault(d.IoErr(), "MakeDirs") THEN END;
    HALT(20);
  END;

  (* make created dir the current, store lock of the dir
  ** we started as we want to get back. *)
  oldCD := d.CurrentDir(newDir);

  LOOP
    newDir := d.CreateDir(name^);
    IF newDir=NIL THEN
      IF d.PrintFault(d.IoErr(), "MakeDirs") THEN END;
      EXIT;
    END;
    (* make again newly created dir the current, now UnLock()
    ** the old current dir
    *)
    prevDir := d.CurrentDir(newDir);
    d.UnLock(prevDir);
    DEC(count);
    IF count=0 THEN EXIT END;
  END;
  (* get back where we started from, unlock the last created dir *)
  prevDir := d.CurrentDir(oldCD);
  d.UnLock(prevDir);
  d.FreeArgs(arguments);
END MakeDirs.
